use serde::Deserialize;
use std::collections::HashMap;

#[derive(Debug, Clone, Deserialize)]
pub struct Config {}

pub type ProjectConfig = HashMap<String, Project>;

#[derive(Debug, Clone, Deserialize)]
pub struct Project {
    pub name: String,
    pub description: String,
    pub icon: Option<String>,
    pub website: Option<String>,
    pub documentation: Option<String>,
    pub since: Option<String>,
    pub contact: Option<ContactInfo>,
    pub sub: Option<ProjectConfig>,
}

#[derive(Debug, Clone, Deserialize)]
pub struct ContactInfo {
    pub email: Option<String>,
}

impl Config {
    pub fn load(path: &str) -> ProjectConfig {
        let content = std::fs::read_to_string(path).unwrap();
        toml::from_str(&content).unwrap()
    }
}

pub fn get_prj(c: &ProjectConfig, path: &str) -> Option<Project> {
    let paths: Vec<_> = path.split("/").filter(|x| !x.is_empty()).collect();
    let name = paths.first()?.to_string();

    if paths.len() == 1 {
        return c.get(&name).cloned();
    } else {
        let sub_prj = c.get(&name)?.sub.as_ref()?;
        get_prj(sub_prj, &paths[1..].join("/"))
    }
}
